Text Representation
-------------------

.. toctree::
   :maxdepth: 2

   huggingface


The `text` module groups classes and configurations that compute
a representation of text -- this includes word embeddings as well
as contextual word embeddings and document embeddings.


.. autoxpmconfig:: xpmir.text.Vocab
.. autoxpmconfig:: xpmir.text.encoders.TextEncoder
   :members: forward
.. autoxpmconfig:: xpmir.text.encoders.DualTextEncoder
   :members: forward
